<?php
/**
 * Bakers Bakery functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Bakers Bakery
 */

if ( ! defined( 'CAKE_SHOP_BAKERY_URL' ) ) {
    define( 'CAKE_SHOP_BAKERY_URL', esc_url( 'https://www.themagnifico.net/themes/bakers-bakery-wordpress-theme/', 'bakers-bakery') );
}
if ( ! defined( 'CAKE_SHOP_BAKERY_TEXT' ) ) {
    define( 'CAKE_SHOP_BAKERY_TEXT', __( 'Bakers Bakery Pro','bakers-bakery' ));
}
if ( ! defined( 'CAKE_SHOP_BAKERY_CONTACT_SUPPORT' ) ) {
define('CAKE_SHOP_BAKERY_CONTACT_SUPPORT',__('https://wordpress.org/support/theme/bakers-bakery','bakers-bakery'));
}
if ( ! defined( 'CAKE_SHOP_BAKERY_REVIEW' ) ) {
define('CAKE_SHOP_BAKERY_REVIEW',__('https://wordpress.org/support/theme/bakers-bakery/reviews/#new-post','bakers-bakery'));
}
if ( ! defined( 'CAKE_SHOP_BAKERY_LIVE_DEMO' ) ) {
define('CAKE_SHOP_BAKERY_LIVE_DEMO',__('https://www.themagnifico.net/demo/bakers-bakery/','bakers-bakery'));
}
if ( ! defined( 'CAKE_SHOP_BAKERY_GET_PREMIUM_PRO' ) ) {
define('CAKE_SHOP_BAKERY_GET_PREMIUM_PRO',__('https://www.themagnifico.net/themes/bakers-bakery-wordpress-theme/','bakers-bakery'));
}
if ( ! defined( 'CAKE_SHOP_BAKERY_PRO_DOC' ) ) {
define('CAKE_SHOP_BAKERY_PRO_DOC',__('https://www.themagnifico.net/eard/wathiqa/bakers-bakery-doc/','bakers-bakery'));
}

function bakers_bakery_enqueue_styles() {
    
    $parentcss = 'cake-shop-bakery-style';
    $theme = wp_get_theme(); wp_enqueue_style( $parentcss, get_template_directory_uri() . '/style.css', array(), $theme->parent()->get('Version'));
    wp_enqueue_style( 'bakers-bakery-style', get_stylesheet_uri(), array( $parentcss ), $theme->get('Version'));

    wp_enqueue_script( 'comment-reply', '/wp-includes/js/comment-reply.min.js', array(), false, true );
    
    wp_enqueue_style( 'flatly-css', esc_url(get_template_directory_uri()) . '/assets/css/flatly.css');
}

add_action( 'wp_enqueue_scripts', 'bakers_bakery_enqueue_styles' );

if ( ! function_exists( 'bakers_bakery_setup' ) ) :
    /**
     * Sets up theme defaults and registers support for various WordPress features.
     *
     * Note that this function is hooked into the after_setup_theme hook, which
     * runs before the init hook. The init hook is too late for some features, such
     * as indicating support for post thumbnails.
     */
    function bakers_bakery_setup() {

        add_theme_support( 'responsive-embeds' );

        // Add default posts and comments RSS feed links to head.
        add_theme_support( 'automatic-feed-links' );

        /*
         * Let WordPress manage the document title.
         * By adding theme support, we declare that this theme does not use a
         * hard-coded <title> tag in the document head, and expect WordPress to
         * provide it for us.
         */
        add_theme_support( 'title-tag' );

        /*
         * Enable support for Post Thumbnails on posts and pages.
         *
         * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
         */
        add_theme_support( 'post-thumbnails' );

        add_image_size('bakers-bakery-featured-header-image', 2000, 660, true);

        /*
         * Switch default core markup for search form, comment form, and comments
         * to output valid HTML5.
         * to output valid HTML5.
         */
        add_theme_support( 'html5', array(
            'search-form',
            'comment-form',
            'comment-list',
            'gallery',
            'caption',
        ) );

        // Set up the WordPress core custom background feature.
        add_theme_support( 'custom-background', apply_filters( 'cake_shop_bakery_custom_background_args', array(
            'default-color' => '',
            'default-image' => '',
        ) ) );

        /**
         * Add support for core custom logo.
         *
         * @link https://codex.wordpress.org/Theme_Logo
         */
        add_theme_support( 'custom-logo', array(
            'height'      => 50,
            'width'       => 50,
            'flex-width'  => true,
        ) );

        add_editor_style( array( '/editor-style.css' ) );

        add_theme_support( 'align-wide' );

        add_theme_support( 'wp-block-styles' );
    }
endif;
add_action( 'after_setup_theme', 'bakers_bakery_setup' );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function bakers_bakery_widgets_init() {
        register_sidebar( array(
        'name'          => esc_html__( 'Sidebar', 'bakers-bakery' ),
        'id'            => 'sidebar',
        'description'   => esc_html__( 'Add widgets here.', 'bakers-bakery' ),
        'before_widget' => '<section id="%1$s" class="widget %2$s">',
        'after_widget'  => '</section>',
        'before_title'  => '<h5 class="widget-title">',
        'after_title'   => '</h5>',
    ) );
}
add_action( 'widgets_init', 'bakers_bakery_widgets_init' );

function bakers_bakery_remove_customize_register() {
    global $wp_customize;
    $wp_customize->remove_section( 'cake_shop_bakery_general_settings' );
}
add_action( 'customize_register', 'bakers_bakery_remove_customize_register', 11 );

